@@ -1,3 +1,4 @@
+import os
 import sys
 from datetime import datetime
 from typing import List
@@ -6,9 +7,10 @@ import click
 
 from r2k.cli import cli_utils, logger
 from r2k.config import config
-from r2k.constants import Parser
-from r2k.ebook.html_builder import build_html
-from r2k.email_sender import send_html, send_urls
+from r2k.constants import ARTICLE_EBOOK_LIMIT, Parser
+from r2k.dates import get_pretty_date_str, now
+from r2k.ebook.epub_builder import create_epub
+from r2k.email_sender import send_epub, send_urls
 from r2k.feeds import Article, Feed
 
 
@@ -27,14 +29,14 @@ def kindle_send(feed_title: str) -> None:
     if feed_title:
         send_articles_for_feed(feed_title)
     else:
-        logger.info("Sending articles from all feeds...")
+        logger.notice("Sending articles from all feeds...\n")
         for feed_title in config.feeds:
             send_articles_for_feed(feed_title)
 
 
 def send_articles_for_feed(feed_title: str) -> None:
     """Find all the new/unread articles for a certain feed and send them to the user's kindle"""
-    logger.info(f"Getting articles from `{feed_title}`...")
+    logger.notice(f"Now working on `{feed_title}`...\n")
 
     local_feed = get_local_feed(feed_title)
     unread_articles = get_unread_articles_for_feed(local_feed)
@@ -66,27 +68,50 @@ def send_updates(unread_articles: List[Article], feed_title: str) -> None:
         if Parser(config.parser) == Parser.PUSH_TO_KINDLE:
             successful_count = send_urls([(article.title, article.link) for article in unread_articles])
         else:
-            successful_count = send_html_book(unread_articles, feed_title)
+            successful_count = send_epub_books(unread_articles, feed_title)
 
-        logger.info(f"Successfully sent {successful_count} articles from the `{feed_title}` feed!")
+        if successful_count:
+            logger.notice(f"\nSuccessfully sent {successful_count} articles from the `{feed_title}` feed!")
+        else:
+            logger.error(f"Failed to send any articles to `{feed_title}`. See errors above")
     else:
         logger.info(f"No new content for `{feed_title}`")
 
 
-def send_html_book(unread_articles: List[Article], feed_title: str) -> int:
-    """Create an HTML book from all the unread articles and send it via email"""
-    html_book = build_html(unread_articles, feed_title)
+def send_epub_books(unread_articles: List[Article], feed_title: str) -> int:
+    """
+    Chunk the list of unread articles into chunks of max size ARTICLE_EBOOK_LIMIT
+
+    This is in order to avoid creating too large of an EPUB and exceeding GMAIL's 25MB attachment size limit
+    """
+    successful_count = 0
+    for i in range(0, len(unread_articles), ARTICLE_EBOOK_LIMIT):
+        successful_count += send_epub_book(unread_articles[i : i + ARTICLE_EBOOK_LIMIT], feed_title)
+    return successful_count
+
+
+def send_epub_book(unread_articles: List[Article], feed_title: str) -> int:
+    """Create an EPUB book from all the unread articles and send it via email"""
     date_range = get_unread_articles_date_range(unread_articles)
     title = f"{feed_title} [{date_range}]"
-    success = send_html(title, html_book)
+    epub_book = create_epub(unread_articles, title)
+    try:
+        success = send_epub(title, epub_book)
+    finally:
+        os.remove(epub_book)
     return len(unread_articles) if success else 0
 
 
 def get_unread_articles_date_range(unread_articles: List[Article]) -> str:
     """Return a nicely formatted string with the range of dates for the article list"""
     if len(unread_articles) == 1:
-        return unread_articles[0].get_str_date(short_date=True)
+        date = unread_articles[0].get_parsed_date()
+        show_year = date.year != now().year
+        return get_pretty_date_str(date, show_year=show_year)
     else:
-        first_date = unread_articles[-1].get_str_date(short_date=True)
-        last_date = unread_articles[0].get_str_date(short_date=True)
-        return f"{first_date} — {last_date}"
+        first_date = unread_articles[0].get_parsed_date()
+        last_date = unread_articles[-1].get_parsed_date()
+        show_year = not (first_date.year == last_date.year == now().year)
+        first_date_str = get_pretty_date_str(first_date, show_year=show_year)
+        last_date_str = get_pretty_date_str(last_date, show_year=show_year)
+        return f"{first_date_str} — {last_date_str}"
